#!/usr/bin/python

import os
import sys
import time
import signal
import optparse

def parseOpts():
    usage = "usage: %prog [options] host filename"
    parser = optparse.OptionParser(usage=usage)
    parser.add_option("-t", "--timeout", type="int", default=30, dest="timeout",
        help="Probe timeout value in seconds (defaults to 30)")
    parser.add_option("-p", "--proxy", dest="proxy", help="Location of X509 " \
        "proxy certificate.")
    parser.add_option("-u", "--cert", dest="usercert", help="Location of " \
        "X509 certificate.")
    parser.add_option("-k", "--key", dest="userkey", help="Location of " \
        "X509 key.")
    opts, args = parser.parse_args()

    if opts.timeout < 0:
        raise ValueError("Timeout value cannot be negative")
    signal.alarm(opts.timeout+1)

    if len(args) != 2:
        parser.print_usage()
        print "Host and filename must be specified"
        sys.exit(1)

    return opts, args

def main():
    opts, args = parseOpts()
    host, filename = args
    url = 'root://%s/%s' % (host, filename)
    cmd = "xrdcp_small %s" % url
    pid = os.fork()
    sys.stdin.close()
    if pid == 0:
        signal.alarm(opts.timeout)
        if opts.proxy:
            os.environ['XrdSecGSIUSERPROXY'] = opts.proxy
        if opts.usercert:
            os.environ['XrdSecGSIUSERCERT'] = opts.usercert
        if opts.userkey:
            os.environ['XrdSecGSIUSERKEY'] = opts.userkey
        os.execvp("xrdcp_small", ["xrdcp_small", url])
    pid, result = os.waitpid(pid, 0)
    if result:
        if os.WIFEXITED(result):
            print "Failed to read file %s; read process exited %i." % (url,
                os.WEXITSTATUS(result))
            sys.exit(2)
        elif os.WIFSIGNALED(result):
            if os.WTERMSIG(result) == signal.SIGALRM:
                print "Failed to read file %s within timeout %i." % (url,
                    opts.timeout)
            else:
                print "Failed to read file %s due to signal %i." % (url,
                    os.WTERMSIG(result))
            sys.exit(2)
        else:
            print "Read process exited due to unknown reason."
            sys.exit(3)
    print "Xrootd server %s appears OK." % host

if __name__ == '__main__':
    main()

